==> zio-aws-apigatewayv2_3-5.17.112.1-sources.jar: zio/aws/apigatewayv2/model/GetVpcLinkRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetVpcLinkRequest(vpcLinkId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetVpcLinkRequest = {
    import GetVpcLinkRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetVpcLinkRequest
      .builder()
      .vpcLinkId(__string.unwrap(vpcLinkId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetVpcLinkRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetVpcLinkRequest.wrap(buildAwsValue())
}
object GetVpcLinkRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetVpcLinkRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetVpcLinkRequest =
      zio.aws.apigatewayv2.model.GetVpcLinkRequest(vpcLinkId)
    def vpcLinkId: __string
    def getVpcLinkId: ZIO[Any, Nothing, __string] = ZIO.succeed(vpcLinkId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetVpcLinkRequest
  ) extends zio.aws.apigatewayv2.model.GetVpcLinkRequest.ReadOnly {
    override val vpcLinkId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.vpcLinkId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetVpcLinkRequest
  ): zio.aws.apigatewayv2.model.GetVpcLinkRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_3-5.17.147.1-sources.jar: zio/aws/apigatewayv2/model/GetVpcLinkRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetVpcLinkRequest(vpcLinkId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetVpcLinkRequest = {
    import GetVpcLinkRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetVpcLinkRequest
      .builder()
      .vpcLinkId(vpcLinkId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetVpcLinkRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetVpcLinkRequest.wrap(buildAwsValue())
}
object GetVpcLinkRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetVpcLinkRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetVpcLinkRequest =
      zio.aws.apigatewayv2.model.GetVpcLinkRequest(vpcLinkId)
    def vpcLinkId: __string
    def getVpcLinkId: ZIO[Any, Nothing, __string] = ZIO.succeed(vpcLinkId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetVpcLinkRequest
  ) extends zio.aws.apigatewayv2.model.GetVpcLinkRequest.ReadOnly {
    override val vpcLinkId: __string = impl.vpcLinkId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetVpcLinkRequest
  ): zio.aws.apigatewayv2.model.GetVpcLinkRequest.ReadOnly = new Wrapper(impl)
}
